/* BUILDMAP.H - contains all the typedefs etc needed for working with
BUILD maps */

typedef struct { // C-STAT - various bit fields related to a sector
	short parallaxed: 1;
	short sloped: 1;
	short xyswap: 1;
	short compressed: 1;
	short flipped: 1;
	short yflipped: 1;
	short relative: 1;
	short filler: 9;
} sectorcstat;

typedef struct { // C-STAT - various bit fields related to a sprite
	short blocking: 1;
	short transparent: 1;
	short xflipped: 1;
	short yflipped: 1;
	short orientation: 2;
	short onesided: 1;
	short realcentering: 1;
	short hitscan: 1;
	short reversetransparent: 1;
	short reserved: 5;
	short invisible: 1;
}	spritecstat;

typedef struct { // C-STAT - various bit fields related to a wall
	short blocking: 1;
	short twotextures: 1;
	short textorient: 1;
	short xflip: 1;
	short masked: 1;
	short oneway: 1;
	short hitscan: 1;
	short translucent: 1;
	short yflip: 1;
	short reversetransparent: 1;
	short reserved: 6;
} wallcstat;

typedef struct { // typedef for a sector
	short wallptr, wallnum;
	signed long ceilingz, floorz;
	sectorcstat ceilingstat, floorstat;
	short ceilingpicnum, ceilingheinum;
	signed char ceilingshade;
	char ceilingpal, ceilingxpanning, ceilingypanning;
	short floorpicnum, floorheinum;
	signed char floorshade;
	char floorpal, floorxpanning, floorypanning;
	char visibility, filler;
	unsigned short lotag, hitag, extra;
} Tsector;

typedef struct // typedef of wall
{
	long x, y;
	short point2, nextwall, nextsector;
	wallcstat cstat;
	short picnum, overpicnum;
	signed char shade;
	char pal, xrepeat, yrepeat, xpanning, ypanning;
	unsigned short lotag, hitag, extra;
} Twall;

typedef struct { // typedef of sprites
	long x, y, z;
	spritecstat cstat;
	short picnum;
	signed char shade;
	char pal, clipdist, filler;
	unsigned char xrepeat, yrepeat;
	signed char xoffset, yoffset;
	short sectnum, statnum;
	short ang, owner, xvel, yvel, zvel;
	unsigned short lotag, hitag, extra;
} Tsprite;

typedef struct { // Info for where player starts
	long posx, posy, posz;
	short angle, cursectnum;
} Tplayerstart;

typedef struct {		/* Definition for what a map consists of */
	long version;
	Tplayerstart playerstart;
	unsigned short numsectors;
	Tsector *sector;
	unsigned short  numwalls;
	Twall *wall;
	unsigned short numsprites;
	Tsprite *sprite;

} Tmap;
